@@ -1,14 +1,15 @@
 from mat3ra.made.material import Material
 from mat3ra.made.tools.build.nanoribbon import NanoribbonConfiguration, create_nanoribbon
 from mat3ra.made.tools.build.nanoribbon.enums import EdgeTypes
-from mat3ra.utils import assertion as assertion_utils
 
-from .fixtures import GRAPHENE, GRAPHENE_ARMCHAIR_NANORIBBON, GRAPHENE_ZIGZAG_NANORIBBON
+from .fixtures.monolayer import GRAPHENE
+from .fixtures.nanoribbon import GRAPHENE_ARMCHAIR_NANORIBBON, GRAPHENE_ZIGZAG_NANORIBBON
+from .utils import assert_two_entities_deep_almost_equal
 
 
 def test_build_zigzag_nanoribbon():
     config = NanoribbonConfiguration(
-        material=Material(GRAPHENE),
+        material=Material.create(GRAPHENE),
         width=2,
         length=4,
         vacuum_width=3,
@@ -16,12 +17,12 @@ def test_build_zigzag_nanoribbon():
     )
 
     nanoribbon = create_nanoribbon(config)
-    assertion_utils.assert_deep_almost_equal(GRAPHENE_ZIGZAG_NANORIBBON, nanoribbon.to_json())
+    assert_two_entities_deep_almost_equal(nanoribbon, GRAPHENE_ZIGZAG_NANORIBBON)
 
 
 def test_build_armchair_nanoribbon():
     config = NanoribbonConfiguration(
-        material=Material(GRAPHENE),
+        material=Material.create(GRAPHENE),
         width=2,
         length=4,
         vacuum_width=3,
@@ -29,4 +30,4 @@ def test_build_armchair_nanoribbon():
     )
 
     nanoribbon = create_nanoribbon(config)
-    assertion_utils.assert_deep_almost_equal(GRAPHENE_ARMCHAIR_NANORIBBON, nanoribbon.to_json())
+    assert_two_entities_deep_almost_equal(nanoribbon, GRAPHENE_ARMCHAIR_NANORIBBON)
